#
# spec file for package libcerror
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcerror
%define lname	libcerror1
Version:        20240413
Release:        1.3
Summary:        Library for C error functions
License:        LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/libyal/libcerror
Source:         https://github.com/libyal/libcerror/releases/download/%version/libcerror-beta-%version.tar.gz
Source2:        https://github.com/libyal/libcerror/releases/download/%version/libcerror-beta-%version.tar.gz.asc
Source9:        %name.keyring
BuildRequires:  c_compiler
BuildRequires:  pkg-config
# Various notes: https://en.opensuse.org/libyal

%description
A library for C error functions.

This package is part of the libyal library collection and is used by
other libraries in the collection.

%package -n %lname
Summary:        Library for C error functions
Group:          System/Libraries

%description -n %lname
A library for C error functions.

This package is part of the libyal library collection and is used by
other libraries in the collection.

%package devel
Summary:        Development files for libcerror, a C error library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
A library for C error functions.

This subpackage contains libraries and header files for developing
applications that want to make use of libcerror.

%prep
%autosetup

%build
echo "V_%version { global: *; };" >v.sym
%configure --disable-static LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep '  local' config.log && exit 1
%make_build

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%ldconfig_scriptlets -n %lname

%files -n %lname
%license COPYING.LESSER
%_libdir/libcerror.so.1*

%files devel
%_includedir/libcerror*
%_libdir/libcerror.so
%_libdir/pkgconfig/libcerror.pc
%_mandir/man3/libcerror.3*

%changelog
* Sat Apr 13 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240413
  * No changelog was provided
* Tue Jan  2 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240101
  * Updates to the testsuite
* Sun Nov 27 2022 Jan Engelhardt <jengelh@inai.de>
- Drop autoreconf call from %%build
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Thu Jan 20 2022 Jan Engelhardt <jengelh@inai.de>
- Force autoreconf run due to patch presence.
* Sat Jan  1 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20220101
  * No changes, just a version bump.
* Wed May 12 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210512 (0f07a7e5)
  * No changelog was provided
* Sun Dec 13 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20201121
  * worked on tests and minor updates
- comment out       # BuildRequires:  pkg-config
  * It started causing build problems
* Mon Mar 25 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- update to v0~20181117
  * worked on tests and minor updates
* Sun Oct  1 2017 Greg.Freemyer@gmail.com
- update to v0~20170824
  * worked on packaging issues for non-linux distros
  * worked on tests
* Wed Feb 15 2017 Greg.Freemyer@gmail.com
- update to v0~20170101
  * moved libcstring macros to common
  * worked on tests
* Wed Jul 13 2016 Greg.Freemyer@gmail.com
- update to v0~20160327
  * 2016 update
  * applied updates
  * updated common
  * worked on tests
* Wed Dec  2 2015 Greg.Freemyer@gmail.com
- update to v0~20150407
  * worked on tests
  * removed USE_CRT_FUNCTIONS support
* Mon Jan  5 2015 Greg.Freemyer@gmail.com
- update to v0~20150101
  * 2015 update - minimal changes
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using libcstring from OBS, not internal version
* Thu Aug 14 2014 Greg.Freemyer@gmail.com
- update to v0~20140105
  * updated dependencies
  * 2014 update
  * fixes in backtrace string creation
  * updated libcstring
* Wed Oct  2 2013 Greg.Freemyer@gmail.com
- update to v0~20130904
  * bug fix for issue under memory limitations
  * code clean up
- make %%description fields slightly more robust
* Sun Jul 28 2013 Greg.Freemyer@gmail.com
- update to v0~20130609
  * fix in .pc.in
  * updated common files
  * additional bounds checking
  * added FORMAT_MESSAGE_IGNORE_INSERTS to FormatMessage calls
  * textual changes
  * updated dependencies
  * 2013 update
- switch to gz compression to eliminate download / conversion process
* Wed Apr  3 2013 jengelh@inai.de
- Initial package (version 0~20121222) for build.opensuse.org
